package Qt::Gui::QWidgetItem;
# THE FOLLOWING CODE IS AUTOMATED, ANY MODIFICATION WILL BE LOST!
# classname: QWidgetItem
# file     : QtGui/qlayoutitem.h

use strict;
use warnings;
#use Carp;

our $VERSION = '0.01_03';
use base qw/Qt::Gui::QLayoutItem/;
#our @ISA = qw/Qt::Gui::QLayoutItem/;


# FIXME: operator overload


1;

=head1 NAME

Qt::Gui::QWidgetItem

=head1 PUBLIC METHODS

=over

=item   QWidgetItem(QWidget * w)

=item  QFlags<Qt::Orientation> expandingDirections()

=item  QRect geometry()

=item  bool hasHeightForWidth()

=item  int heightForWidth(int arg0)

=item  bool isEmpty()

=item  QSize maximumSize()

=item  QSize minimumSize()

=item  void setGeometry(const QRect & arg0)

=item  QSize sizeHint()

=item  QWidget * widget()


=back

=head1 ENUM VALUES

=over


=back

=head2 EXPORT

None by default.

=head1 AUTHOR

Dongxu Ma E<lt>dongxu@cpan.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2011 - 2011 by Dongxu Ma

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

See L<http://dev.perl.org/licenses/artistic.html>

=cut
